/*******************************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM Corporation - initial API and implementation
 * yyyymmdd bug      Email and other contact information
 * -------- -------- -----------------------------------------------------------
 * 20061128          pmoogk@ca.ibm.com - Peter Moogk, Initial coding
 *******************************************************************************/

package org.eclipse.example.webservice.runtime.ui;

import org.eclipse.wst.command.internal.env.core.data.DataMappingRegistry;
import org.eclipse.wst.command.internal.env.ui.widgets.INamedWidgetContributor;
import org.eclipse.wst.command.internal.env.ui.widgets.INamedWidgetContributorFactory;
import org.eclipse.wst.command.internal.env.ui.widgets.SimpleWidgetContributor;
import org.eclipse.wst.command.internal.env.ui.widgets.WidgetBindingToWidgetFactoryAdapter;
import org.eclipse.wst.command.internal.env.ui.widgets.WidgetContributor;
import org.eclipse.wst.command.internal.env.ui.widgets.WidgetContributorFactory;
import org.eclipse.wst.command.internal.env.ui.widgets.WidgetDataContributor;

public class BeanConfigWidgetFactory implements INamedWidgetContributorFactory {

	private SimpleWidgetContributor  configWidgetContrib;
	private SimpleWidgetContributor  optionalWidgetContrib;
  private DataModel                model;
	
	public BeanConfigWidgetFactory()
	{	  
	}
	
	public INamedWidgetContributor getFirstNamedWidget() 
	{
    if( configWidgetContrib == null ) init();
    
	  return configWidgetContrib;
	}

	public INamedWidgetContributor getNextNamedWidget( INamedWidgetContributor widgetContributor) 
	{
    if( configWidgetContrib == null ) init();
    
	  return widgetContributor == configWidgetContrib && model.isOptionalPage1() 
           ? optionalWidgetContrib : null;
	}
	
	public void registerDataMappings(DataMappingRegistry dataRegistry) 
	{
    // Map the data model from the defaulting command to this widget factory.
    // The framework will actually to the call to getWebServiceDataModel in
    // the ExampleDefaultingCommand class and then call the setWebServiceDataModel
    // method in this class.
    dataRegistry.addMapping( ExampleDefaultingCommand.class, 
                             "WebServiceDataModel", 
                             BeanConfigWidgetFactory.class );
	}
  
  public void setWebServiceDataModel( DataModel model )
  {
    this.model = model;
  }
  
  private void init()
  {
    BeanConfigWidget beanConfigWidget = new BeanConfigWidget( model );
    OptionalBeanConfigWidget optionalWidget = new OptionalBeanConfigWidget( model );
    
    // The strings below have not been put into a properties file to make this
    // example code more readable.  Web services extenders should put all user
    // readable strings into a properties file for translation.
    configWidgetContrib  = createWidgetContributor( "Example BU Config page title",
                                                    "Some text describing this example BU config page", 
                                                    beanConfigWidget );
    
    optionalWidgetContrib  = createWidgetContributor( "Example BU optional page title",
                                                      "Some text describing this example BU optional page", 
                                                      optionalWidget );
  }
  
  private SimpleWidgetContributor createWidgetContributor( String title, String description, final WidgetDataContributor contributor )
  {
    SimpleWidgetContributor widgetContrib  = new SimpleWidgetContributor();
    widgetContrib.setTitle(title);
    widgetContrib.setDescription(description);
    widgetContrib.setFactory( new WidgetContributorFactory()
                              {
                                public WidgetContributor create()
                                {
                                  return contributor;
                                }
                              });
    
    return widgetContrib;
  }   
}
