/*******************************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM Corporation - initial API and implementation
 * yyyymmdd bug      Email and other contact information
 * -------- -------- -----------------------------------------------------------
 * 20061128          pmoogk@ca.ibm.com - Peter Moogk, Initial coding
 *******************************************************************************/
package org.eclipse.example.webservice.runtime.ui;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.wst.command.internal.env.ui.widgets.SimpleWidgetDataContributor;
import org.eclipse.wst.command.internal.env.ui.widgets.WidgetDataEvents;


public class SkelConfigWidget extends SimpleWidgetDataContributor 
{
  private DataModel model;
  private Button    validationButton;
  
  public SkelConfigWidget( DataModel model )
  {
    this.model = model;  
  }
  
  public WidgetDataEvents addControls( Composite parent, final Listener statusListener )
  {
    Composite  mainComp = new Composite( parent, SWT.NONE );
    GridLayout layout   = new GridLayout();
    GridData   griddata = new GridData( GridData.FILL_BOTH );
    Label      label    = new Label( mainComp, SWT.NONE );
    
    mainComp.setLayout( layout );
    mainComp.setLayoutData( griddata );
    label.setText( "This composite is for the TD example scenario (page 1)." );

    final Button optionalPage1 = new Button( mainComp, SWT.CHECK );
    optionalPage1.setSelection(model.isOptionalPage1());
    
    optionalPage1.setText( "Do you want to see TD page 2?" );
    optionalPage1.addSelectionListener( new SelectionAdapter()
                                       {
                                         public void widgetSelected(SelectionEvent e)
                                         {
                                           model.setOptionalPage1(optionalPage1.getSelection() );
                                           
                                           // Need to trigger a validation at this point to ensure
                                           // that the next button is enabled properly just in case
                                           // this is the last page in the wizard.
                                           statusListener.handleEvent( null );
                                         }     
                                       });  
    
    final Button optionalPage2 = new Button( mainComp, SWT.CHECK );
    optionalPage2.setSelection(model.isOptionalPage2());
    
    optionalPage2.setText( "Do you want to see TD page 3?" );
    optionalPage2.addSelectionListener( new SelectionAdapter()
                                       {
                                         public void widgetSelected(SelectionEvent e)
                                         {
                                           model.setOptionalPage2(optionalPage2.getSelection() );
                                           
                                           // Need to trigger a validation at this point to ensure
                                           // that the next button is enabled properly just in case
                                           // this is the last page in the wizard.
                                           statusListener.handleEvent( null );
                                         }     
                                       });  
    
    
    validationButton = new Button( mainComp, SWT.CHECK );
    
    // This widget will be validated each time this button is selected.
    validationButton.addListener( SWT.Selection, statusListener );
    validationButton.setText( "Don't even think about selecting this check box!!" );
    
    return this;
  }
  
  /* (non-Javadoc)
   * @see org.eclipse.wst.command.env.ui.widgets.WidgetContributor#getStatus()
   */
  public IStatus getStatus() 
  {
    IStatus result = null;
    
    if( validationButton.getSelection() )
    {
      result = new Status( IStatus.ERROR, "id", 0, "You just invalidated this page by checking that button!", null ); 
    }
    
    return result;
  }
}
